Struct

MalcontentSessionLimits

since: 0.5.0

Description [src]

struct MctSessionLimits {
  /* No available fields */
}

An opaque, immutable structure which contains a snapshot of the session limits settings for a user at a given time.

This includes whether session limits are being enforced, and the limit policy — for example, the times of day when a user is allowed to use the computer.

Typically, session limits settings can only be changed by the administrator, and are read-only for non-administrative users. The precise policy is set using polkit.

Available since: 0.5.0

Functions

mct_session_limits_deserialize

Deserialize a set of session limits previously serialized with mct_session_limits_serialize().

since: 0.7.0

Instance methods

mct_session_limits_check_time_remaining

Check whether the user has time remaining in which they are allowed to use the computer.

unstable since: 0.14.0

mct_session_limits_equal

Check whether session limits configurations a and b are equal.

unstable since: 0.14.0

mct_session_limits_get_daily_limit

Get the daily limit, if set.

unstable since: 0.14.0

mct_session_limits_get_daily_schedule

Get the daily schedule session limits, if set.

unstable since: 0.14.0

mct_session_limits_get_user_id

Get the user ID of the user this MctSessionLimits is for.

since: 0.5.0

mct_session_limits_is_enabled

Check whether any session limits are enabled and are going to impose at least one restriction on the user.

since: 0.7.0

mct_session_limits_ref

Increment the reference count of limits, and return the same pointer to it.

since: 0.5.0

mct_session_limits_serialize

Build a GVariant which contains the session limits from limits, in an opaque variant format.

since: 0.7.0

mct_session_limits_unref

Decrement the reference count of limits. If the reference count reaches zero, free the limits and all its resources.

since: 0.5.0